<?
namespace admin\view;

class TranslationManager
{
	public function show()
	{
		global $lang , $sys;

		$out = \admin\view\PagePanel::show( true , false , false , $lang -> getTrans( 'T_TLUMACZENIA' ) );

		$dbrowse = new \DataBrowse( 'pcms_lang_text' );
		$dbrowse -> addPosition( 'text'	, $lang -> getTrans( 'T_TEKST' )      , '' , '' , '' , true );
		$dbrowse -> addPosition( 'pl'   , $lang -> getTrans( 'T_POLSKI' )     , '' , '' , '' , true );
		$dbrowse -> addPosition( 'en' 	, $lang -> getTrans( 'T_ANGIELSKI' )	, '' , '' , '' , true );
		$dbrowse -> addPositionSimple( $lang -> getTrans( 'T_EDYTUJ' ) 	, '' , 'index.php?rw=edit' );
		$dbrowse -> addPositionSimple( $lang -> getTrans( 'T_USUN' )	, '' , '' , $sys -> deleteAction() );
		$dbrowse -> setParam( 'id' );
		$dbrowse -> addSort( 'text ASC' );
		$dbrowse -> addLp();
		$dbrowse -> setLimit( 25 );
		$dbrowse -> addFiltr( 'text' 	, $lang -> getTrans( 'T_TEKST' ) 	, 'text' );
		$dbrowse -> addFiltr( 'pl' 		, $lang -> getTrans( 'T_POLSKI' ) 	, 'text' );
		$out .= $dbrowse -> draw();

		return $out;
	}

	public function edit( $id = '' )
	{
		global $lang;

		$out = \admin\view\PagePanel::show( false , true , true , $lang -> getTrans( 'T_TLUMACZENIA' ) );

		$dbedit = new \DataEdit( 'pcms_lang_text' , 'id' , $id );
    if ( $id )
      $dbedit -> addPosition( 'text' 	, $lang -> getTrans( 'T_TEKST' )      , 'label' );
    else
      $dbedit -> addPosition( 'text' 	, $lang -> getTrans( 'T_TEKST' )      , 'text' );
		$dbedit -> addPosition( 'pl'    , $lang -> getTrans( 'T_POLSKI' )     , 'textarea' );
		$dbedit -> addPosition( 'en'    , $lang -> getTrans( 'T_ANGIELSKI' )	, 'textarea' );
		$dbedit -> addPosition( 'ru'    , $lang -> getTrans( 'T_ROSYJSKI' )   , 'textarea' );
		$dbedit -> addPosition( 'de'    , $lang -> getTrans( 'T_NIEMIECKI' )   , 'textarea' );
		$dbedit -> addPosition( 'uk'    , $lang -> getTrans( 'T_UKRAINSKI' )   , 'textarea' );
		$out .= $dbedit -> draw();

		return $out;
	}
}